package util

import "sync"

// LockingStructMap is a lockable map[string]
type LockingStructMap struct {
	sync.RWMutex
	data map[string]struct{}
}

// NewLockingStructMap will create a new lockingStructMap
func NewLockingStructMap() LockingStructMap {
	return LockingStructMap{
		data: make(map[string]struct{}),
	}
}

// Get will Rlock and return the value of a key in a lockingStructMap
func (m *LockingStructMap) Get(key string) (val struct{}, ok bool) {
	m.RLock()
	defer m.RUnlock()
	val, ok = m.data[key]
	return val, ok
}

// Set will lock and set a key in a lockingStructMap
func (m *LockingStructMap) Set(key string, val struct{}) {
	m.Lock()
	defer m.Unlock()
	m.data[key] = val
}
